# dxcore
<a href="https://teamcity.tek-pi.com/viewType.html?buildTypeId=Dxcore_Build&guest=1">
<img src="https://teamcity.tek-pi.com/app/rest/builds/buildType:(id:Dxcore_Build)/statusIcon"/>
</a>

Core Library of DXL

